@@ -1,25 +1,37 @@
 # EXAMPLE
 from sklearn.datasets import make_blobs
-import clusteval
-print(clusteval.__version__)
-print(dir(clusteval))
+# import clusteval
+# print(clusteval.__version__)
+# print(dir(clusteval))
 
 from clusteval import clusteval
 
 # %%
+import numpy as np
 from sklearn.datasets import make_blobs
-
 from clusteval import clusteval
-ce = clusteval(cluster='dbscan')
-X, labels_true = make_blobs(n_samples=50, centers=[[1, 1], [-1, -1], [1, -1]], cluster_std=0.4,random_state=0)
 
-# Import library
-from clusteval import clusteval
-# Set the method
-ce = clusteval(cluster='hdbscan')
+# X, y = make_blobs(n_samples=500, centers=[[1, 1], [-1, -1], [1, -1]], cluster_std=0.4,random_state=0)
+
+X, labx = make_blobs(n_samples=200, n_features=2, centers=2, random_state=1)
+c = np.random.multivariate_normal([40, 40], [[20, 1], [1, 30]], size=[200,])
+d = np.random.multivariate_normal([80, 80], [[30, 1], [1, 30]], size=[200,])
+e = np.random.multivariate_normal([0, 100], [[200, 1], [1, 100]], size=[200,])
+X = np.concatenate((X, c, d, e),)
+
+
 # Evaluate
+# ce = clusteval(cluster='dbscan', params_dbscan={'epsres' :100, 'norm':True})
+ce = clusteval(cluster='dbscan')
 results = ce.fit(X)
 ce.plot()
+ce.scatter(X)
+
+# Set the evaluation method
+# ce = clusteval(cluster='hdbscan')
+# results = ce.fit(X)
+# ce.plot()
+# ce.scatter(X)
 
 # %% Check
 from sklearn.datasets import make_blobs
@@ -36,8 +48,8 @@ cluster_labels = results['labx']
 import clusteval
 df = clusteval.import_example()
 del df['PassengerId']
-import df2onehot
-dfhot = df2onehot.df2onehot(df, excl_background='0.0')['onehot']
+from df2onehot import df2onehot
+dfhot = df2onehot(df, excl_background='0.0')['onehot']
 X = dfhot.values
 
 from clusteval import clusteval
@@ -97,9 +109,9 @@ X, labels_true = make_blobs(n_samples=50, centers=[[1, 1], [-1, -1], [1, -1]], c
 # X, labels_true = make_blobs(n_samples=750, centers=6, n_features=10)
 
 # %% Silhouette
-# ce = clusteval(method='silhouette', metric='kmeans', savemem=True)
+# ce = clusteval(evaluate='silhouette', metric='kmeans', savemem=True)
 from clusteval import clusteval
-ce = clusteval(method='silhouette', verbose=3)
+ce = clusteval(evaluate='silhouette', verbose=3)
 results = ce.fit(X)
 ce.plot()
 ce.scatter(X)
@@ -116,7 +128,7 @@ results['order_rows']
 
 # %% Silhouette
 from clusteval import clusteval
-ce = clusteval(method='silhouette')
+ce = clusteval(evaluate='silhouette')
 results = ce.fit(X)
 ce.plot()
 ce.scatter(X)
@@ -128,7 +140,7 @@ for i in zip(results['labx'], results_dendro['labx']):
 
 # %% dbindex
 from clusteval import clusteval
-ce = clusteval(method='dbindex')
+ce = clusteval(evaluate='dbindex')
 results = ce.fit(X)
 ce.plot()
 ce.scatter(X)
@@ -142,7 +154,7 @@ for i in zip(results['labx'], results_dendro['labx']):
 
 # %% derivative
 from clusteval import clusteval
-ce = clusteval(method='derivative')
+ce = clusteval(evaluate='derivative')
 results = ce.fit(X)
 ce.plot()
 ce.scatter(X)
@@ -180,20 +192,38 @@ for i in zip(results['labx'], results_dendro['labx']):
 # %% Directly use the dbindex method
 import clusteval
 from sklearn.datasets import make_blobs
-X, labels_true = make_blobs(n_samples=750, centers=6, n_features=10)
+import matplotlib.pyplot as plt
+X, labels_true = make_blobs(n_samples=750, centers=4, n_features=10)
+
+
+X, labx = make_blobs(n_samples=200, n_features=2, centers=2, random_state=1)
+c = np.random.multivariate_normal([40, 40], [[20, 1], [1, 30]], size=[200,])
+d = np.random.multivariate_normal([80, 80], [[30, 1], [1, 30]], size=[200,])
+e = np.random.multivariate_normal([0, 100], [[200, 1], [1, 100]], size=[200,])
+X = np.concatenate((X, c, d, e),)
+
+
+plt.figure()
+fig, axs = plt.subplots(2,4, figsize=(25,10))
 
 # dbindex
 results = clusteval.dbindex.fit(X)
-fig,ax = clusteval.dbindex.plot(results)
+_ = clusteval.dbindex.plot(results, title='dbindex', ax=axs[0][0], visible=False)
+axs[1][0].scatter(X[:,0], X[:,1],c=results['labx']);axs[1][0].grid(True)
 
 # silhouette
 results = clusteval.silhouette.fit(X)
-fig,ax = clusteval.silhouette.plot(results)
+_ = clusteval.silhouette.plot(results,title='silhouette', ax=axs[0][1], visible=False)
+axs[1][1].scatter(X[:,0], X[:,1],c=results['labx']);axs[1][1].grid(True)
 
 # derivative
 results = clusteval.derivative.fit(X)
-fig,ax = clusteval.derivative.plot(results)
+_ = clusteval.derivative.plot(results,title='derivative', ax=axs[0][2], visible=False)
+axs[1][2].scatter(X[:,0], X[:,1],c=results['labx']);axs[1][2].grid(True)
 
 # dbscan
 results = clusteval.dbscan.fit(X)
-fig,ax1,ax2 = clusteval.dbscan.plot(results)
+_ = clusteval.dbscan.plot(results,title='dbscan', ax=axs[0][3], visible=False)
+axs[1][3].scatter(X[:,0], X[:,1],c=results['labx']);axs[1][3].grid(True)
+
+plt.show()
